poudriere is a tool primarily designed to test package production on
FreeBSD. However, most people will find it useful to bulk build ports
for FreeBSD.
===> The following configuration options are available for poudriere-devel-3.4.99.20260425:
BASH=on: Install programmable completions for Bash
EXAMPLES=on: Build and/or install examples
MANIFESTS=on: Install manifests for jail creation
PORTCONFIG=on: Install portconfig for options command
QEMU=off: Add qemu-user-static for non-x86 architectures
ZSH=on: Install programmable completions for zsh
===> Use 'make config' to modify these settings
Update to 3.1.4-58-gd237819
Changes:
Fix not setting proper UNAME_m/p for powerpc64 cross build
Fix qemu builds not setting MACHINE/MARCHINE_ARCH in make.conf
QEMU: No need to set MACHINE/MACHINE_ARCH in env.
QEMU: For consistency set UNAME_m/p in jail's login.conf.
Don't let balance_pool() failure crash a builder.
Avoid double ln(1) when called in a clean_pool/stop_build failure from
build_pkg
When a build crashes and does not complete, properly cleanup its builder
jail.
bulk queue optimizations
Call pkg_cache_data in a separate worker. This allows build_pkg() to finish
quicker.
bulk -t/testport: Fix the first package built in a jail not showing its
needed shared libraries.
Disable 'set -x' in some noisy functions
Rewrite lock_acquire() to not spam 'sleep 0.1'
(Only the first 15 lines of the commit message are shown above )
Update to 3.1.3-6-g784f9aa
Changes:
- jail -cx: Fix incorrect hard linking.
- Support building powerpc from powerpc64 without qemu.
- Document that '.' is not allowed in -jzp
- jail_start: Enforce no '.' in -jzp.
Update to 3.1.1-41-g00ae908
Changes:
- Fix 'cp: File Exists' and 'identical (not copied)' errors
- jail -u: Fix freebsd-update for EOL and non-TTY usage
- ATOMIC_PACKAGE_REPOSITORY: Fix crash if user removes the dir .latest
refers to
- Update to 3.1.1-33-gbf2a55b
(I decided to use 'git-describe --tags' now that USE_GITHUB supports it)
Changes:
- Allow overriding jail params with JAIL_PARAMS
- Remove old nxb-bin directory if needed.
- Fix more cases of running from local checkout
- Allow all COLOR variables to be overridden in poudriere.conf.
- testport -c is fixed
- bulk now creates a copy of /var/db/ports to avoid breakage if the
directory in /usr/local/etc/poudriere.d/options is touched during a build.
- XDEV: Remove /bin/sh /bin/csh from the static hardlink list on mips/mips64
as there are endian issues to work out.
For the new USE_GITHUB with only GH_TAGNAME set default DISTNAME to
include GH_PROJECT/GH_ACCOUNT/GH_TAGNAME. This prevents the distfile
having the same name despite changing one of these values and causing
a bad checksum.
Differential Revision: https://reviews.freebsd.org/D2103
Reviewed by: mat
With hat: bdrewery
Update to checkin 54183f5f
Changes:
- When using TMPFS_LOCALBASE (TMPFS_ALL) always try to clone the ref
jail's LOCALBASE to the builder jail on port build startups. There
is an optimization to not do this but it is needed for 'jail start'
hooks that want to customize LOCALBASE. It normally will be a NOP.
Fix the new USE_GITHUB to rename the distfile such that it does not
conflict with the old scheme and cause a "reroll" or "invalid checksums". This
also avoids clobbering the FreeBSD distcache.
Use a revision in the DISTNAME for USE_GITHUB in case we need to bump this
again for anything. It's more a hint of how to handle it in the future.
Reported by: mat
Discused with: mat, antoine, swills
With hat: portmgr
Remove GITHUB_RELEASE MASTER_SITE from r375010 as it is now redundant with
GITHUB.
The new GITHUB MASTER_SITE from r381618 now supports not setting GH_COMMIT and
only having GH_TAGNAME default to DISTVERSION.
All of these ports as-is.
With hat: portmgr
Update to checkin 80b7167
Changes:
- Clean up language of the zsh completion for bulk -c and -C.
- Manpage fixes
- jail: Fix handling of games distribution for recent CURRENT.
- testport: Show error when unable to extract pkg
- jail -uc: Support a SETNAME-src.conf
- Add 'builder' start/stop hook. Params: id mnt
- Add a check to see if id(1) works in the jail.
- HTML: Show proper percentage in progress bar.
- Fix creating cpdup ignore files in jail if cpdup is not used (ZFS).
- Cross-building updates
- Update to 3.1.1 which fixes pkg(8) crashing in 8.4 jails.
8.4 jails should be recreated if created with Poudriere 3.1 or
poudriere-devel-3.0.99.20141117.
- Update to checkin 8d28349
The next update will be 3.1-RC1.
Changes:
* The HTML interface is now fixed for file:// and direct access. This
currently only works for the build directory. The jail-level and top-level
do not yet work, but may in the future.
* Fix usage over NFS when root does not have access to current directory.
* Fix performance for qemu/native-xdev by not using /bin/sh for pkg(8)'s
ABI_FILE
Update to checkin d2f5c83
Changes:
* Minor display fixes
* poudriered cleanups
* ports -l: Support -n like jail
* Add a 'jail stop' hook called right before jail is shutdown
* Auto fix shadowed files in repository that are owned by pkg(8)
* jail -cx: TARGET/TARGET_ARCH fixes
- Update to checkin 96b7698
Changes:
* Fix another race in balance_ool() causing crashed builds
* More color fixes
* jail -u: Fix detection of invalid jails
* Better handling of crashed builds
* Fix incremental rebuild for pkg/pkg-devel
- Update to checkin 4555dff [now a git hash]
- Poudriere's home has moved to https://github.com/freebsd/poudriere/wiki
Changes:
* Fix some error handling with the recent races fixes, which led to them
still crashing.
* Display some nicer errors in some cases rather then just exiting.
* jail -m null: Fix /etc/login.conf.db being stale after deleting
the jail.
* Fix a possible case of dependency calculation errors being lost.
- Update to checkin d7e95d9102
Changes:
* HTML: Fix NaN showing in a case
* Fix handling of SIGPIPE for cleaning up.
* Improvements to cleanup handling such that recursive errors will not
stop the cleanup process.
* HTML: Add an apache example
* testport: Allow tee(1) more time to flush buffer before killing it off.
* bulk: Remove the use of tee(1)
* bulk: Fix several races leading to "stuck_in_queue" and "Unknown stuck
queue bug".
* jail -m src=: Also copy in the src tree now. .git and .svn are ignored.
* bulk: Fix high CPU usage/spinning when the queue is waiting on the last
jobs to finish.
* Remove use of stripcolors pipe which used far too much CPU.
* bulk: Fix a case where computing deps was not delaying errors until
the end of deps calculation was intended.
- Update to checkin 7c2b030b2b
Changes:
* testport: Detect invalid origin in -o
* Still symlink logs to errors/ for 'stuck_in_queue'
* Add a jail:start hook. Can be used to customize the jail for builds on
startup.
* jail -u: Stop trying to nullmount /usr/src on top of itself, and
fix /compat warning.
* bulk -t/testport: Only show NEEDED libraries using readelf(1) rather than
ldd(1) which was showing indirect library dependencies.
* bulk -R / NO_RESTRICTED: Show which files are being removed by
clean_restricted
* Fix showing missing MOVED as a warning
* jail -i: Fix to not require a ports tree
* bulk -i: Fix installation of ports-mgmt/pkg
- Update to checkin 439a908c73
Changes:
* ports -u: Fix with git
* bulk: Some dependency failures are now delayed rather than immediately
fatal. This allows identifying more build problems rather than
needing to iteratively run bulk to continue finding more.
* Add a note that DEVELOPER is ignored without bulk -t/testport.
* Also remove DEVELOPER_MODE for ports not being tested. (pkg uses it and
causes fatal pkg-lstat errors on bad plist)
* Only show boost priority if actually building the packages listed
* Add PKG_REPO_META_FILE passthrough for repo meta file for pkg-repo. Not
currently useful so undocumented. It will be more useful when pkg-repo -m
learn mores metadata options and there is a client-side way to view the
metadata.
(Only the first 15 lines of the commit message are shown above )
- Update to checkin bbac739f86
Changes:
* Workaround regression with pkg-1.3 causing all packages to have new options.
* status: Fix -H to be tab-delimited
- Update to checkin 6d00750ddc
Changes:
* HTML: Fix printing of "Remaining" on the jail page
* Build reason: Change "missing LDFLAGS" to "missing_LDFLAGS" to have a one
word reason
* Update example nginx config for 1.6: nginx 1.6 now includes
application/json in default mime.times
* Add USE_PROCFS and USE_FDESCFS to allow disabling requirement on them
- Update to checkin df5632bbea
Changes:
* bulk: Always clean restricted packages when done building if NO_RESTRICTED
is set
* bulk: Don't rebuild unneeded deps which were not specified on the cmdline.
NOTE: This means that partial builds will not create a consistent repo of
other existing packages. I.e., running bulk PORT1 PORT2 and then
running bulk PORT1 will make it only create a consistent repo
for PORT1. Always build with the ports you expect to be there.
* Fix 'msg_error' not defined errors.
* pkgclean/distclean: Consider hardlinks for size calculation
* distclean:
- Fix some false-positives
- Support multiple -p options
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 3a2569440b
- Fix build on 9.1 which does not have F_DUPFD_CLOEXEC
Changes:
* status/jail -l: Fix sort(1) error on <10
* Fix crash with SIGINFO done too early in build
* Prevent appending the same make.conf multiple times
* Fix (-s) showing in sanity when pkg is missing
* Fix jail -u
* jail -u: Name the jail with -default so it can be stopped
with jail -k.
* Add ALLOW_MAKE_JOBS_PACKAGES which lets the named package globs
to always run with MAKE_JOBS regardless of ALLOW_MAKE_JOBS. Default
is set to allow 'pkg' and 'ccache' to build with MAKE_JOBS as they
typically holdup the rest of the build.
* No longer run 'make clean' before building a port as it is not needed
due to always using a WRKDIRPREFIX
* Fix -a to work with bad-styled category Makefiles
* sem(4) is only needed on <9
- Update to checkin f86a423218
Changes:
* Reduce jail restarting for networking access by now always starting
2 jails. One with networking support and one without. This allows
not constantly restarting jails to enable/disable networking, which
causes a lot of jail lock contention.
* Color support has been added. This is disabled by any of:
1. poudriere -N <sub-command>
2. stdout or stderr NOT in a TTY (piped)
3. USE_COLORS=no in poudriere.conf
* Add DURATION_FORMAT and BUILDTIME_FORMAT to allow changing time
display and default build name.
* madvise(MADV_PROTECT) the main poudriere process to allow it to cleanup
on failure from out-of-swap.
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 32a2683eca
Changes:
- Queue is now priotitized by the dependency-chain
length and not by number of direct dependencies.
- Add PRIORITY_BOOST in poudriere.conf which takes
PKGNAME globs to boost up to the top of the queue.
Example:
PRIORITY_BOOST="apache-openoffice* pypy* mysql-workbench*"
- bulk/testport: Add -k to keep going on test failures.
The failures are stll considered failures but do not skip
further builds depending on that port.
- bulk -at: This now defaults to -k
- Leftovers and Orphan checking now uses the scripts in
ports so we can update them frequently without a poudriere
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 0966e62bc4
- Cleanup Makefile to use pkg-plist [1]
Changes:
- make_index fixes (use ports/portsnap version now)
- Documentation updates
- Use autotools for build
- All incremental messages are in a consistent format now.
- New daemon poudriered using libucl with fine-grained permissions, but
not yet hooked up or documented. It will be hooked up to poudriere-queue
and documented soon.
- Add an nc(1) wrapper to work around src change r249499.
- status: Add -H for scripted mode
- status: Show URL if available
- Allow to specify revision when running poudriere jail -u with svn method
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 74abc9e1c2
Changes:
* bulk: Support port origins ending in /
* ATOMIC_PACKAGE_REPOSITORY: Fix bulk/testport when running on 9.1,8.4,8.3
as they do not support mv(1) -h to rename a symlink. This is fixed by
adding a custom rename(1) that just calls rename(2) on the arguments
to ensure an atomic rename(2) is done.
- Update to checkin 32dddce6d7
- Update LICENSE format
Changes:
- Add a BUILDER_HOSTNAME that can be set to define the hostname
for package building
- Add PRESERVE_TIMESTAMP (default off) to allow preserving timestamps
in svn checkouts
- Auto clean packages when their version does not match the jail's version
- jail -l: Add -n to only show name
- Ensure /sbin:/usr/sbin is in PATH
- jail: Add -r to rename jails (jail -r newname -j oldname)
- Fix ipv6-only usage
- Require sem(4) kernel support as some ports require it
- Update to checkin 105ef35755
Changes:
- Fix hang in sanity check
- Fix race causing "unknown stuck queue" after ports finish building
- Fix PARALLEL_JOBS always set to prepare number
- Cache fixes
- cpdup -X usage fixes
- bulk: Avoid rollback on first startup (speeds up startup)
- Cleanup some error handling with parallel processes,
errors will now cause a 30 second wait for other processes
to cleanly exist instead of sending a SIGKILL right away.
- Fix KEEP_OLD_PACKAGES_COUNT when package root
is a symlink
- Ignore home directory of users created by ports during
leftover check
- Load MOVED on startup and use it to track changed origins
in existing packages, which fixes more invalid dependency errors
and "new dependency" deletions in sanity check.
- Checksum is now done as root in case it needs to refetch
- testport: Remove extra -J description
- Update to checkin ae87e905f3
Changes:
* Fix sanity checking not properly recursively deleting dependencies.
* bulk/testport: Add PREPARE_PARALLEL_JOBS and -J n[:P] where P is
used for pre-build parallel jobs which may be more IO-bound
* Typo fixes in manpage
- Update to checkin a9e8799172
Changes:
* Add new MAX_MEMORY and TMPFS_LIMIT to allow limiting memory
* bulk: Show (-C) when used when deleting existing packages
* bulk: for install,deinstall,package,extract limit execution
time to 1 hour to avoid endless loops like devel/meta-cvs in
r337304
* Allow BUILDNAME to be overridden in poudriere.conf, such as:
BUILDNAME=$(TZ=UTC date +%Y%m%dT%H%M%SZ)
- Update to checkin e5f36a7de8
Changes:
* Package builds are now atomic. They will not update the
package repository directory until the build finishes.
This can be disabled with ATOMIC_PACKAGE_REPOSITORY (default yes).
This will convert the repository to a new format on first build.
If a build fails, all of the successful packages are retained
for the next attempt, but the old packages do not get modified.
* Disabling COMMIT_PACKAGES_ON_FAILURE (default yes) will have it
not touch the repository if the build fails; the package repository
will only be updated once a build succeeds.
* bulk now has a dry run mode (-n). Requires ATOMIC_PACKAGE_REPOSITORY
* Add KEEP_OLD_PACKAGES which will keep KEEP_OLD_PACKAGES_COUNT
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 7f33ec2fcb
Changes:
* pkgclean: Fix to properly remove correct duplicated package
* Only markfs prepkg for bulk/testport, not pkgclean
* jail -l: Fix crash if no jails defined
- Update to checkin ab7af29666
Changes:
* pkgclean: Detect and cleanup duplicated packages due to PKGNAME
renaming
* Misc typo fixes
* ports -m git
- Use --depth=1 to not download all history for the repository.
- Support -v to show output
- Update to checkin 725ea5afcf
Changes:
* poudriere.8: Document that -j is required for bulk
* bulk/testport: Delete packages that have changed PKGNAME during startup,
which will avoid pkg-repo duplicate package warnings/bugs. This will not
clean up existing duplicates, just fix new ones going forward.
* bulk: Fix start hook starting before validations
- Update to checkin cf519772ff
Changes:
* Fix random crashes with parallel process handling
* sanity check is now parallelized for a big speedup
* Pkg deleting during startup has been optimized further
to avoid a bottleneck during parallelization
* jail -cu: Disable CCACHE on 10
* Manpage typo fix
* testport/bulk -t: Fix staging absolute link checking with files
that have spaces
* testport: Fix so that MAKE_JOBS runs by default
* bulk -t: Fix so that MAKE_JOBS does not run by default
* testport: Fix so that the port being tested shows in the web ui.
Note that this is still in data/logs/bulk/
- Update to checkin fbd0b7e356
Changes:
* Loopback address fixes
* Fixes for when running poudriere in a jail (do not use fdescfs or
devfs to hide/unhide devices). PATCHED_FS_KERNEL overrides this
* Prevent SIGTSTP from reaching child builders
* jail -c: Fix -m ftp-archive for 9.0
* jail -cu: Add svnlite support and SVN_CMD override
- Update to checkin 7761067198
Changes:
* testport: Fix /prefix error when using pkg_install
* Fix sample bulk.sh hook for stats
* Don't set PREFIX when using 'testport -n', which avoids
hiding cases where bsd.port.pre.mk are needed
- Update to checkin 7761067198
Changes:
* Add BUILD_AS_NON_ROOT and set to 'no' by default. Set to 'yes' to
attempt to build ports as non-root. Ports may need USES=uidfix to
build, or NEED_ROOT=yes to mark as requiring root
* Check for absolute symlinked files when staging
- Update to checkin 40778eb80f
Changes:
- Non-root build fixes
- Added BUILD_AS_NON_ROOT and disable by default until more wide
testing can be done. Set to yes to build ports as non-root where
possible
Mark as NEED_ROOT for now as it fails to stage otherwise
===> src/bin (install)
install -o root -g wheel -m 555 poudriere.sh
/wrkdirs/usr/ports/ports-mgmt/poudriere-devel/work/stage/usr/local/bin/poudriere
install:
/wrkdirs/usr/ports/ports-mgmt/poudriere-devel/work/stage/usr/local/bin/poudriere:
chown/chgrp: Operation not permitted
- Update to checkin bba1e59a04
Changes:
- Many usage/notices cleaned up
- Some default invokations now work as expected
- jail -cu: http method now supported
- Non-root package building is now in for staged ports that do
not have NEED_ROOT. It defaults to building as 'nobody', but
can be overridden by changing PORTBUILD_USER in poudriere.conf
- Fix detecting {/,/usr,/usr/local} on staged NO_MTREE ports
- Update to checkin 926c783293
Changes:
- Respect DESTDIR on poudriere install
- testport -i: Fix when orphans are found with staging
- bulk -v: Reword distfiles message
- bulk: Fix INDEX building showing wrong origins
- bulk: Remove stray " done" message
- Staging fixes for testing ports-mgmt/pkg
- jail: Deprecate csup
- Add safety check for rm -rf /*
- pkgclean: Fix finding packages [1]
- During build, call install-mtree after run-depends. This should be
a NOP, but mentioned in case weird things happen.
Reported by: olgeni
- Update to checkin 6a4cc74775
This release supports upcoming STAGE support. Please
update to it soon.
Changes:
- Staging support.
* Detect files orphaned in the stagedir that are not
installed due to not being in the pkg-plist
* Detect files that get installed outside of the
STAGEDIR during 'make stage' as 'stage_fs_violation'
- Rename 'preinst_fs_violation' to 'build_fs_violation'
- latest-per-pkg links are now hardlinks
- Fix possible recursive crash during jail startup
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 0eb89d4f74
Changes:
ports: Add -k for -d usage to keep files around after deleting
testport -i: Fix TERM not being passed into the jail
jail -cu: Fix build with recent head due to new user 'unbound'
Hardlink logs into latest and latest-per-pkg
Fix recursive crash in jail_stop()
Add TIMESTAMP_LOGS support
Set build dir to 0700 to avoid gvfsd-trash tracking all mounts during build
- Update to checkin 63ec9efc9a
Changes:
- HTML interface now use DataTables for pagination/searching/sorting
- NO_FORCE_PACKAGE added to prevent setting FORCE_PACKAGE
- New pkgclean subcommand for removing unwanted/unneeded packages.
Similar concept as 'pkg autoremove', but for the repository.
- testport -i: Fix for when the build fails
- testport: Add hint about using -n when leftovers are found
- Switch to using USE_PACKAGE_DEPENDS_ONLY
- Fixes for detecting errors in startup, such as missing fdescfs
support
- Improved runaway output
- Update to checkin 6abae2a52c
Changes:
* Speedup sanity checks by only checking ports that are required
by the build and not all existing packages.
* Switch to embedded cpdup(1) for creating jails instead of pax(1)
* Implement port blacklisting defined in
etc/poudriere.d/[(setname|jailname)-]blacklist
* Add hooks for bulk start/stop
* status: Always show actual path to logs instead of /latest
* bulk: Add check for missing PKGNAME (empty port dir)
* Disable tracking buildtimes by default
TRACK_BUILDTIMES=yes to enable
* bulk: Fixed dependency calculation for CHECK_CHANGED_DEPS.
There are still some ports with issues.
* Add portbuild/tinderbox error reasons [1]
Submitted by: linimon [1]
Update to checkin 5b2608fcc7
Changes:
* HTML: Always redirect /latest/ to the actual build URL
* HTML: Name build names as YYYY-MM-DD_HHhMMmSSs to remove ':'
to make completions/URL encoding nicer.
* Leftover updates
* ports -u: Always 'svn upgrade' before updating (for 1.7->1.8)
* Fix SVN compatibility with 1.8 for URL recording
* jail -s now starts networking
* Fix jail building on recent HEAD [requires devel/fmake on host]
* Pre-liminary support for mips64/armv6
See: https://fossil.etoilebsd.net/poudriere/info/f781dc0560
* Repo building now always occurs if the repo is missing.
* bulk -c: Fix deleting old caches
* Allow user to override etc dir via POUDRIERE_ETC and -e switch
See: https://fossil.etoilebsd.net/poudriere/info/5b2608fcc7
- Update to checkin 2f8d07b10c
Changes:
- Fix parallel_exec child errors not stopping the build.
I.e., when computing deps if an origin is not found, the
build was not properly detecting that.
- Be more strict about leftovers in /var/db
- Package filename quoting fixes
- Update to checkin e38d69a149
Changes:
- Jail tar(1) and pkg(8) invokations
- Remove unneeded ldd temp script
- Fix appending MASTERNAME-make.conf twice [1]
- Use swap-based disk for MDMFS [2]
- HTML: Move assets into assets/ so that tab completion
is not hindered for logs/ by logo.jpg
Reported by: kwm [1]
Submitted by: ak [2]
- Update to checkin c61b908704
Changes:
- Leftover fixes
- Status fixes
- ports-mgmt/pkg no longer required in the host when building
WITH_PKGNG sets.
- CCACHE fixes
- jail: Support -m url= [1]
- jail -u: Allow updating snapshot jails [1]
- jail: Fix destroying/cleanup of jails with USE_TMPFS=all
- HTML: Show skipped counts in failed/ignored tables
- HTML: Show SVN URL
- Allow DISTFILES_CACHE=PORTSDIR/distfiles now that DISTFILES
are mounted in /distfiles [2]
- testport: Make failed builds more clear [3]
Submitted by: will [1]
Reported by: mat [2]
Reported by: tj [3]
- Update to checkin c6bbdcc441
Changes:
- Add example hook in etc/poudriere.d/hooks
- Documentation cleanups
- Sanity check fixes (ports tree exists)
- SIGINT during build no longer register the build as
'crashed'
- status: Fix cases where this would change the status of
the actual build
- queue/daemon - Use a UNIX domain socket for scheduling builds
instead of requiring the 'queue' user to have write access to
the queue dir.
- bulk -t: Add -r flag to recursively test dependencies (this was
the old default behavior)
- Revert linux leftover change - this is now handled in ports
r318960
- Update to checkin 45d02f1ed1
Changes:
- Add rc script
- jail -c: Fix NO_ZFS support
- bulk -t: Only test ports specified, not unlisted depends
- make_index: Jail the INDEX building
- options: Fix *make.conf not being respected
- Add workaround for ZFS zteardown deadlock on 9.0/9.1-RELEASE
- status: Fix when running multiple builds at once
- leftovers: Ignore shared library cache files
- Various fixes
- Update to checkin 9d45276ee9 which should become 3.0
Changes:
- Add new subcommand 'status' which lists running builds. Specify
-j[pz] to view the current status of a specific build and all of
its jobs.
- Missing/New Dependencies: Be more verbose by default about why
packages are being deleted.
- CHECK_CHANGED_OPTIONS now defaults to verbose
- Add CHECK_CHANGED_DEPS and default it to on
- Fix support for jails with ':' in them
- bulk: Allow specifying -f multiple times
- testport -i: Add hostname into /etc/hosts
- Documentation fixes
- Fix DISABLE_MAKE_JOBS support
- Fix dependencies being checked twice during port builds when not
port testing
- jail -u fixes for freebsd-update/ftp
- Fix buildtime tracking missing a space
- Update to checkin 6cbcb7e1bb
Changes:
- Add new latest-per-pkg symlinks into the root
bulk/ dir and bulk/jail/ dirs to link back to
the most recent builds for each package
- Use new CCACHE_DIR support
- Fix JS error in HTML page when loading too early
- Fix trying to clean '*' due to race condition when
skipping packages
- Remove CCACHE_CPP2 from jail -c as latest devel/ccache
is already handling this for buildworld
- Fix linux ports hanging during build
- Fix jail -c on recent CURRENT by using DB_FROM_SRC
- Update to checkin 47f0b3b35d
Changes:
- testport/bulk -t: Fix leftover detection for TMPFS LOCALBASE
- Add bpf* to list of devices to unhide to fix libnet10
- Use --fast-read (-q) option of tar when possible
- Fix hanging when building some linux ports
- testport -i: Fix terminal not being fully usable, ie for vi(1)
- Fix depends failures not halting port building
- Major speedups for NO_ZFS/USE_TMPFS startup/cloning
- Mount /usr/src as read-only in every builder jail. This also
saves using ~1GB of memory for every builder when using TMPFS
- testport/bulk -t: Add checks to look for filesystem being touched
before 'make install'
- Fix some cases where poudriere would hang when errors were
encountered
- Various documentation/typo fixes
- Support value of 'no' for NO_RESTRICTED and SAVE_WRKDIR
- jail -d: Ensure jail not running before deleting
Feature safe: yes
- Update to checkin c9d23c4740
Changes:
- Skip deleting symlinks/empty dirs with -s
- Fix pkg_install builds [1]
- Fix SETNAME-options not working [2]
- ports: Fix cleanup when create is aborted
- ports: Add -v to show more output for SVN operations
- bulk: Add -N to skip generating package repository or INDEX
- Show CONFIGURE_ENV/CONFIGURE_ARGS/MAKE_ENV in build logs
- Add support for PTNAME-options
Submitted by: Jimmy Olgeni <olgeni@olgeni.com> [1,2]
Feature safe: yes
- Update to checkin 52e5de4fd8
Changes:
- Install depends just-in-time in the proper sequence ordering, instead of
all upfront.
This also fixes differences between testport and bulk with regards to
run-depends.
- Give a port all the special depends distfiles it needs during build as
well. This fixes
issues with fetching and distfiles.
- Add basic hook support in /usr/local/etc/poudriere.d/hooks
- bulk: New C index builder for pkg_* bulks
- bulk: Automatically detect direct dependency changes. This should detect
postgresql/mysql/perl updates (change of default versions) without
needing user interraction.
- Delete empty directories when cleaning up repositories
- Add ftp-archive method for old releases
- jail: consistently accept svn revision number
(Only the first 15 lines of the commit message are shown above )
- Update to checkin 51586b2049 which will eventually become 3.0
This codebase has been in testing for several months now and
is stable
- Remove standard description for ZSH
Changes:
- ZFS support is now optional:
* NO_ZFS can be set to disable ZFS usage
* TMPFS_ALL can be used to the build 100% in memory via tmpfs
- Jail/Port properties are no longer stored in ZFS. They will
be automatically converted on the first execution. This means
that downgrading to 2.x is not easily possible.
- testport has lost -d
- Remove cron
- Add daemon (rc script not completed yet)
(Only the first 15 lines of the commit message are shown above )
- Update to checkin e9eb1d10aa which will become 2.4.
2.4 will be the last major release in 2.x. Once 2.4
is released, this devel port will be updated to 3.0
which optionally supports NO ZFS!!
- Convert tab to space in WWW
Changes:
- cron: This is now deprecated and will be replaced in 3.0 with a daemon
- testport: -d support has been deprecated and will be removed in 3.0. Use
-p instead.
- bulk: The queue is now processed through a priority based on how many
other ports depend on the port that is ready-to-build [1]
- bulk: Add -R option to remove RESTRICTED packages after building
- bulk: Fix INDEX building
- Builds now mount packages, ports, distfiles and options as read-only
They are allowed to have changes made only in specific phases. Note that
(Only the first 15 lines of the commit message are shown above )
Number of commits found: 334 (showing only 100 on this page)